% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GroupClustering.R
\name{FormGroupsClusters}
\alias{FormGroupsClusters}
\title{Group effects given the pairwise p-values}
\usage{
FormGroupsClusters(
  PvaluesMatrix,
  CI = NULL,
  Effects,
  SignificanceLevel = 0.05,
  UpperCase = FALSE,
  RankLabels = TRUE,
  PlotAdj = FALSE,
  padjust = NULL,
  CalcClusters = FALSE,
  digits = 4,
  col = "lightblue",
  labelsCol = "black",
  space2max = 0,
  UseGrouping = TRUE,
  ylim = NULL,
  main = "",
  ylab = "",
  xlab = "",
  lty = 1,
  drawAxis = TRUE,
  rightshift = 0,
  additionalTextGrouping = "",
  superpose = FALSE,
  cex.grouping = 1,
  cex.ticks = 0.1,
  cex.lab = 1,
  ylog = FALSE
)
}
\arguments{
\item{PvaluesMatrix}{a matrix containing the p-values of the comparisons of each possible pairs of effects in the lower triangle (excluding the diagonal)}

\item{CI}{a matrix containing with three columns containint the effects, the lower limits and the upper limits of a confidence interval for the effects (default = NULL, indicating that no confidence intervals are available)}

\item{Effects}{a vector containing the effects}

\item{SignificanceLevel}{the significance level of the pairwise comparisons (default = 0.05)}

\item{UpperCase}{should upper case letters be used for labelling the groups (default is FALSE)}

\item{RankLabels}{should the labels of the grouping be sorted according to the value of the response (default=TRUE)}

\item{PlotAdj}{should the associated graph be printed(default = FALSE)}

\item{padjust}{method for correcting the p-values (before the calculations are performed) as in the function p.adjust (Default is NULL, indicating that no multiple testing corrections are used)}

\item{CalcClusters}{should the clusters be calculated and displayed instead of grouping (Default is FALSE)}

\item{digits}{number of digits in the output (default = 4)}

\item{col}{the colour of the bars (default = "lightblue")}

\item{labelsCol}{the colour of the bars (default = "black")}

\item{space2max}{space between the upper limit of the confidence interval and the label¨}

\item{UseGrouping}{should the grouping be added to the plots (default = TRUE)}

\item{ylim}{range of the vertical axis}

\item{main}{character with the title of the plot (default = '')}

\item{ylab}{label of the vertical axis}

\item{xlab}{label of the horizontal axis}

\item{lty}{type of line}

\item{drawAxis}{should the axis be drawn (default = TRUE)}

\item{rightshift}{a number specifying a (small) right shift of the line}

\item{additionalTextGrouping}{character vector with additional text to the grouping}

\item{superpose}{should the graph be superposed to an existing graph (default = FALSE)}

\item{cex.grouping}{size of the labels of groups}

\item{cex.ticks}{size of the thicks defining the the limits of the confidence intervals}

\item{cex.lab}{size of the labels}

\item{ylog}{should the vertical axis be expressed in a logarithmic scale (default = FALSE)}
}
\value{
an object of (S3) class "PostHoc"
}
\description{
Group effects given the pairwise p-values
}
\details{
This is an auxiliar function forming a contrast matrix of all possible. Generates an error if n is smaller than 2.
}
\examples{
MM <- glm(Y ~ Treatment+0,  data=DeIdentifiedExample)
GG <- posthoc(MM)
Effects <- coef(MM)
PvaluesMatrix <- GG$PvaluesMatrix
TT <- FormGroupsClusters(PvaluesMatrix = PvaluesMatrix, Effects = Effects)
plot(TT)
}
\author{
Rodrigo Labouriau
}
\keyword{pairwise-comparisons}
\keyword{post-hoc}
