% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GroupClustering.R
\name{posthoc}
\alias{posthoc}
\title{Group effects for GLMs and GLMMs}
\usage{
posthoc (Model, EffectIndices = NULL, EffectLabels = NULL,
         EffectsMatrix = NULL, ParBootstrap = FALSE, Nboots = 999,
         SignificanceLevel = 0.05, UpperCase = FALSE,
         RankLabels = TRUE, WaldApproximation = FALSE,
         CalcClusters = FALSE, QUIET = TRUE, PlotAdj = FALSE,
         digits = 4, padjust = NULL,
         Scale = 1.0, Location = 0.0, isBinomialModel = FALSE,
         col = "lightblue", labelsCol = "black", space2max = 0,
         UseGrouping = TRUE, ylim = NULL,
         main = "", ylab = "", xlab = "", lty = 1, drawAxis = TRUE,
         rightshift = 0, additionalTextGrouping = "", superpose = FALSE,
         cex.grouping = 1.0, cex.ticks = 0.1, cex.lab = 1, ylog = FALSE)
}
\arguments{
\item{Model}{a model of class lm, glm, glmerMod, lme or gls.}

\item{EffectIndices}{a vector containing the indices of the effects to be analysed (default = NULL, indicating that all the levels are used).}

\item{EffectLabels}{a character vector with the labels of the effects (default = NULL, which implies that the corresponding labels of the model coefficient are used).}

\item{EffectsMatrix}{matrix defining contrasts to be compared (bypasses the EffectIndices, default is NULL, meaning that standard inference is performed).}

\item{ParBootstrap}{logic flag indicating whether the confidence intervals should be calculated with parametric bootstrap (default is false, i.e. the Wald confidence interval is used).}

\item{Nboots}{number of bootstrap samples used for the confidence interval. (default = 999).}

\item{SignificanceLevel}{the significance level of the pairwise comparisons (default = 0.05).}

\item{UpperCase}{should upper case letters be used for labelling the groups (default is FALSE).}

\item{RankLabels}{should the labels of the grouping be sorted according to the value of the response (default=TRUE)}

\item{WaldApproximation}{logic flag indicating whether a Wald approximated test should be used (defaut = FALSE).}

\item{CalcClusters}{should the clusters be calculated and displayed instead of grouping (Default is FALSE)}

\item{QUIET}{flag indicating whter the (large) output of the multcomp library should be temporarily re-directed (default = TRUE).}

\item{PlotAdj}{should the associated graph be printed(default = FALSE).}

\item{digits}{number of digits in the output (default = 4)}

\item{padjust}{method for correcting the p-values (before the calculations are performed) as in the function p.adjust (Default is NULL, indicating that no multiple testing corrections are used)}

\item{Scale}{a scaling factor multiplying the output table (default = 1, i.e., no scaling is used).}

\item{Location}{a location term added to the output table (default = 0, i.e., no location shift is performed).}

\item{isBinomialModel}{a logical flag indicating whther the model is a binomial model different than the Bernoulli (default = FALSE, i.e. not a binomial model).}

\item{col}{the colour of the bars (default = "black")}

\item{labelsCol}{the colour of the bars (default = "black")}

\item{space2max}{space between the upper limit of the confidence interval and the label¨}

\item{UseGrouping}{should the grouping be added to the plots (default = TRUE)}

\item{ylim}{range of the vertical axis}

\item{main}{character with the title of the plot (default = '')}

\item{ylab}{label of the vertical axis}

\item{xlab}{label of the horizontal axis}

\item{lty}{type of line}

\item{drawAxis}{should the axis be drawn (default = TRUE)}

\item{rightshift}{a number specifying a (small) right shift of the line}

\item{additionalTextGrouping}{character vector with additional text to the grouping}

\item{superpose}{should the graph be superposed to an existing graph (default = FALSE)}

\item{cex.grouping}{size of the labels of groups}

\item{cex.ticks}{size of the thicks defining the the limits of the confidence intervals}

\item{cex.lab}{size of the labels}

\item{ylog}{should the vertical axis be expressed in a logarithmic scale (default = FALSE)}
}
\value{
an object of (S3) class "PostHoc"
}
\description{
posthoc is used to group or cluster the effects of liner, generalised linear and generalised linear mixed models according to significance of pairwise tests comparing the levels of the effects.
}
\details{
Perform post hoc analyses via pairwise comparisons of all the effect levels, or of a supplied subset of effects (using the parameter "EffectIndices") or even linear combinations of effects (using the parameter "EffectsMatrix")
}
\examples{
MM <- glm(Y ~ Treatment+0,  data=DeIdentifiedExample)
GG <- posthoc(MM)
print(GG)
}
\author{
Rodrigo Labouriau
}
\keyword{pairwise-comparisons}
\keyword{post-hoc}
